==> haskell-hls-call-hierarchy-plugin-2.1.0.0-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-DU8QKALrXP0JqZPrYKPJ7f
key:                  hls-call-hierarchy-plugin-2.1.0.0-DU8QKALrXP0JqZPrYKPJ7f
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  2db395bf299add7215a04fb8a8d26e0c
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-DU8QKALrXP0JqZPrYKPJ7f
depends:
    aeson-2.1.2.1-1NeIvw5bSkQ9apxHmCtPBl base-4.17.2.1 containers-0.6.7
    extra-1.7.16-FVFc4gt4avs4Z4Fwytd6v6
    ghcide-2.1.0.0-3keJNlZm06oCdlYkMesWmq
    hiedb-0.4.3.0-4L53W4cm2KXj59rVz6wf7
    hls-plugin-api-2.1.0.0-IqykGQB4fwV7MRx4ktscim
    lens-5.3.2-3lnPesktvu71I24tA5AXig
    lsp-2.1.0.0-66TR94wq2QwHvgBT8EMSua
    sqlite-simple-0.4.19.0-GRq55OAKrf7CXemoVxF1Du text-2.0.2
    unordered-containers-0.2.20-1s4f8pAJmee27mGfYrIk99

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-call-hierarchy-plugin-2.1.0.0-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-LYC1CTnZ9hInPCoOTCxrw
key:                  hls-call-hierarchy-plugin-2.1.0.0-LYC1CTnZ9hInPCoOTCxrw
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  616e8bafb07856423c9948f1d996b8a3
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-LYC1CTnZ9hInPCoOTCxrw
depends:
    aeson-2.1.2.1-Kx5U0b11hXDAcrJPuBeHuf base-4.17.2.1 containers-0.6.7
    extra-1.7.16-5tezMKqv9GA6gNR4q67AdR
    ghcide-2.1.0.0-JFanyDP6TiN9YNvtBtscgo
    hiedb-0.4.3.0-7e1rhLFa4m3KpoT04ElRCf
    hls-plugin-api-2.1.0.0-JEKlXQXeaW9Ka0MbLGh5py
    lens-5.3.2-LURSnBuXCqTHeh00mrfrRc
    lsp-2.1.0.0-BoTbUL4sYUS2PxK0z5SmEn
    sqlite-simple-0.4.19.0-9qchQV9oRZ5EEMiNjoClOy text-2.0.2
    unordered-containers-0.2.20-Jnp6Xrk1NDm4qrPXFyeyaF

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
